@@ -13,7 +13,7 @@ from ..testing import validate_entry
 
 
 log = logging.getLogger(__name__)
-default_meta = {"author": "unknown", "short_description": "no description"}
+default_meta = {"author": "unknown", "short_description": "no description", "tags": []}
 
 
 @click.group(help="The RECAST Analysis Catalogue")
@@ -53,31 +53,34 @@ def create(name, path):
         )
     )
 
+
 @catalogue.command()
 def paths():
     paths = config.catalogue_paths()
-    out = '\n'.join(['* '+x for x in paths])
+    out = '\n'.join(['* ' + x for x in paths])
     click.secho('Paths considered by RECAST:\n--------------------------')
     click.secho(out)
 
+
 @catalogue.command()
 @click.argument("path")
 def add(path):
     path = os.path.realpath(path)
     if os.path.exists(path) and os.path.isdir(path):
-        paths = config.catalogue_paths(include_default = False)
+        paths = config.catalogue_paths(include_default=False)
         paths.append(path)
         paths = sorted(list(set(paths)))
         click.secho("export RECAST_ATLAS_CATALOGUE=" + ":".join(paths))
     else:
-        log.warning("path %s does not exist or is not a directory",path)
+        log.warning("path %s does not exist or is not a directory", path)
         raise click.Abort()
 
+
 @catalogue.command()
 @click.argument("path")
 def rm(path):
     path = os.path.realpath(path)
-    paths = config.catalogue_paths(include_default = False)
+    paths = config.catalogue_paths(include_default=False)
     filtered_paths = [p for p in paths if p != path]
     filtered_paths = sorted(list(set(filtered_paths)))
     if not filtered_paths:
@@ -85,10 +88,11 @@ def rm(path):
     else:
         click.secho("export RECAST_ATLAS_CATALOGUE=" + ":".join(filtered_paths))
 
+
 @catalogue.command()
 def ls():
-    fmt = "{0:35}{1:60}{2:20}"
-    click.secho(fmt.format("NAME", "DESCRIPTION", "EXAMPLES"))
+    fmt = "{0:35}{1:60}{2:20}{3:20}"
+    click.secho(fmt.format("NAME", "DESCRIPTION", "EXAMPLES", "TAGS"))
 
     for k, v in sorted(config.catalogue.items(), key=lambda x: x[0]):
         click.secho(
@@ -96,6 +100,7 @@ def ls():
                 k,
                 v.get("metadata", default_meta)["short_description"],
                 ",".join(list(v.get("example_inputs", {}).keys())),
+                ",".join(v.get("metadata", default_meta).get('tags', [])),
             )
         )
 
@@ -113,7 +118,10 @@ description  : {short:20}
 author       : {author}
 toplevel     : {toplevel}
 """.format(
-        author=metadata.get("author",'N/A'), name=name, short=metadata.get("short_description","N/A"), toplevel = data['spec']['toplevel']
+        author=metadata.get("author", 'N/A'),
+        name=name,
+        short=metadata.get("short_description", "N/A"),
+        toplevel=data['spec']['toplevel'],
     )
     click.secho(toprint)
 
@@ -123,7 +131,7 @@ toplevel     : {toplevel}
 @click.argument("example")
 def example(name, example):
     data = config.catalogue[name]
-    if not example in data.get("example_inputs", {}):
+    if example not in data.get("example_inputs", {}):
         click.secho("example not found.")
         return
     click.secho(yaml.dump(data["example_inputs"][example], default_flow_style=False))
